@@ -1,10 +1,9 @@
+#![doc = include_str!("../README.md")]
+
 mod de; pub use de::*;
 
 #[cfg(test)] mod tests;
 
-macro_rules! md_test { ($x:expr) => { #[cfg(doctest)] #[doc = $x] extern {} }; }
-md_test!(include_str!("../README.md"));
-
 fn from_utf8(s: &[u8], mut location: Location) -> Result<&str, DeserializeError> {
 	std::str::from_utf8(s)
 		.map_err(|e| {
