@@ -6,7 +6,7 @@ fn test() {
 		strings: Vec<String>,
 	}
 
-	let s = b"
+	let t: Test = crate::from_bytes("
 numbers: # Before
 	1
 	2
@@ -18,10 +18,7 @@ strings:
 	foo
 	foo bar # inline
 	not-a-key: foo
-";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <Test as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+").unwrap();
 	assert_eq!(t, Test{
 		numbers: vec![1, 2, 3],
 		strings: vec!["foo".into(), "foo bar".into(), "not-a-key: foo".into()],
@@ -37,25 +34,22 @@ fn multi_line() {
 		dicts: Vec<std::collections::HashMap<String, u8>>,
 	}
 
-	let s = b"
-strings:
-	single-line
+	let t: Test = crate::from_bytes("
+		strings:
+			single-line
 
-	:
-		multi-line
-		string!
+			:
+				multi-line
+				string!
 
-	single-line
-dicts:
-	:
-		foo: 1
-		bar: 2
-	:
-		baz: 3
-";
-
-	let mut d = crate::Deserializer::from(buffered_reader::Memory::new(s));
-	let t = <Test as serde::de::Deserialize>::deserialize(&mut d).unwrap();
+			single-line
+		dicts:
+			:
+				foo: 1
+				bar: 2
+			:
+				baz: 3
+	").unwrap();
 	assert_eq!(t, Test{
 		strings: vec!["single-line".into(), "multi-line\nstring!".into(), "single-line".into()],
 		dicts: vec![
